#!/usr/bin/env python
# -*- coding: utf-8 -*-

import scribus
import os.path

#write out all versions of reference

#files to save to, and the layers that make up those files
#does not include Everyone, because everyone gets that layer.
files = {}
files['Prophet'] = ['Prophet','Players']
files['Sorceror'] = ['Sorceror', 'Mnemonic Sorceror', 'Players']
files['Classical Sorceror'] = ['Sorceror', 'Classical Sorceror', 'Players']
files['Thief'] = ['Thief','Players']
files['Warrior'] = ['Warrior','Players']
files['Monk'] = ['Monk','Players']
files['Adventure Guide'] = ['Adventure Guide',]


#set all layers to not print, except Everyone and the given list
def setPrintableLayers(printableSet):
	printableSet.append('Everyone')
	for layer in scribus.getLayers():
		if layer in printableSet:
			scribus.setLayerPrintable(layer, True)
		else:
			scribus.setLayerPrintable(layer, False)
	return

def getPrintableLayers():
	printableLayers = []
	for layer in scribus.getLayers():
		if scribus.isLayerPrintable(layer):
			printableLayers.append(layer)
	return printableLayers
			

#don't do anything unless there's a document open
if scribus.haveDoc():
	#remember the current printable layers
	originalLayers = getPrintableLayers()
	
	#get the folder to save to
	#fileDialog seems to require three unnamed arguments
	saveTo = scribus.fileDialog('Select folder to save reference PDFs', 'Directories', "", isdir=True)
	if saveTo:
		#for every PDF, make the right layers printable and save to the chosen folder
		for file in files.keys():
			filename = os.path.join(saveTo, file + '.pdf')
			setPrintableLayers(files[file])
			
			pdf = scribus.PDFfile()
			pdf.file = filename
			pdf.save()
		
		#restore printable layer settings
		setPrintableLayers(originalLayers)
else:
	scribus.messageBox("No Open Document", "You need to have the Gods & Monsters reference open to use this script.")
